@@ -90,6 +90,9 @@ curl ${FnUrl}
 {"KEY2":"VALUE2","KEY1":"VALUE1","KEY3":"VALUE3"}
 ```
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
