@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-secret-manager-wrapper-layer",
-    "2.0.363",
+    "2.0.630",
     __name__[0:-6],
-    "cdk-secret-manager-wrapper-layer@2.0.363.jsii.tgz",
+    "cdk-secret-manager-wrapper-layer@2.0.630.jsii.tgz",
 )
 
 __all__ = [
